FlutterLaranjinhaPayment class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deviceInfo(
) → Future< LaranjinhaDeviceInfo> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pay(
{required LaranjinhaPaymentPayload paymentPayload}) → Future< LaranjinhaPaymentResponse> -
print(
{required LaranjinhaPrintPayload printPayload}) → Future< void> -
refund(
{required LaranjinhaRefundPayload refundPayload}) → Future< LaranjinhaRefundResponse> -
reprint(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited