MethodChannelFlutterLaranjinhaPayment class

An implementation of FlutterLaranjinhaPaymentPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deviceInfo() Future<LaranjinhaDeviceInfo>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pay({required LaranjinhaPaymentPayload paymentPayload}) Future<LaranjinhaPaymentResponse>
override
print({required LaranjinhaPrintPayload printPayload}) Future<void>
override
refund({required LaranjinhaRefundPayload refundPayload}) Future<LaranjinhaRefundResponse>
override
reprint() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited