LaranjinhaPaymentResponse class

Constructors

LaranjinhaPaymentResponse({required String storeName, required String date, required String time, required double value, String? auto, String? nsu, String? issuerName, String? cardHolderName, String? terminalNumber, String? cv, String? aid, String? arqc, int? installments, double? installmentValue, String? cnpj, String? operationType, String? maskedPan, String? pixTransactionId})
LaranjinhaPaymentResponse.fromJson({required Map<String, dynamic> json})
factory

Properties

aid String?
final
arqc String?
final
auto String?
final
cardHolderName String?
final
cnpj String?
final
cv String?
final
date String
final
hashCode int
The hash code for this object.
no setterinherited
installments int?
final
installmentValue double?
final
issuerName String?
final
maskedPan String?
final
nsu String?
final
operationType String?
final
pixTransactionId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeName String
final
terminalNumber String?
final
time String
final
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited